==> wildfly-ee-dist-24.0.0.Beta1-src.zip: wildfly-24.0.0.Beta1-src/testsuite/integration/manualmode/src/test/java/org/jboss/as/test/manualmode/ejb/client/outbound/connection/transaction/preparehalt/TransactionalBean.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2020, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.manualmode.ejb.client.outbound.connection.transaction.preparehalt;

import org.jboss.as.test.integration.transactions.PersistentTestXAResource;
import org.jboss.as.test.integration.transactions.TransactionCheckerSingleton;
import org.jboss.logging.Logger;

import javax.annotation.Resource;
import javax.ejb.EJB;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.transaction.Transaction;
import javax.transaction.TransactionManager;

/**
 * Bean expected to be called by {@link ClientBean}.
 * Working with {@link javax.transaction.xa.XAResource}s to force the transaction manager to process
 * two-phase commit after the end of the business method.
 */
@Stateless
public class TransactionalBean implements TransactionalRemote {
    private static final Logger log = Logger.getLogger(TransactionalBean.class);

    @EJB
    private TransactionCheckerSingleton transactionCheckerSingleton;

    @Resource(lookup = "java:/TransactionManager")
    private TransactionManager tm;

    @TransactionAttribute(TransactionAttributeType.MANDATORY)
    public void enlistOnePersistentXAResource() {
        try {
            log.debugf("Invocation to #enlistOnePersistentXAResource with transaction", tm.getTransaction());
            tm.getTransaction().enlistResource(new PersistentTestXAResource(transactionCheckerSingleton));
        } catch (Exception e) {
            throw new IllegalStateException("Cannot enlist single " + PersistentTestXAResource.class.getSimpleName()
                    + " to transaction", e);
        }
    }

    @TransactionAttribute(TransactionAttributeType.MANDATORY)
    public void intermittentCommitFailure() {
        try {
            Transaction txn = tm.getTransaction();
            log.debugf("Invocation to #intermittentCommitFailure with the transaction: %s", txn);
            txn.enlistResource(new TestCommitFailureXAResource(transactionCheckerSingleton));
        } catch (Exception e) {
            throw new IllegalStateException("Cannot enlist single " + TestCommitFailureXAResource.class.getSimpleName()
                    + " to the transaction", e);
        }
    }

    @TransactionAttribute(TransactionAttributeType.MANDATORY)
    public void intermittentCommitFailureTwoPhase() {
        try {
            Transaction txn = tm.getTransaction();
            log.debugf("Invocation to #intermittentCommitFailure with transaction: %s", txn);
            txn.enlistResource(new TestCommitFailureXAResource(transactionCheckerSingleton));
            txn.enlistResource(new PersistentTestXAResource(transactionCheckerSingleton));
        } catch (Exception e) {
            throw new IllegalStateException("Cannot enlist one of the XAResources " + TestCommitFailureXAResource.class.getSimpleName()
                    + " or " + PersistentTestXAResource.class.getSimpleName() + " to the transaction", e);
        }
    }
}

==> wildfly-ee-dist-33.0.0.Beta1-src.zip: wildfly-33.0.0.Beta1-src/testsuite/integration/manualmode/src/test/java/org/jboss/as/test/manualmode/ejb/client/outbound/connection/transaction/preparehalt/TransactionalBean.java <==
/*
 * Copyright The WildFly Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package org.jboss.as.test.manualmode.ejb.client.outbound.connection.transaction.preparehalt;

import org.jboss.as.test.integration.transactions.PersistentTestXAResource;
import org.jboss.as.test.integration.transactions.TransactionCheckerSingleton;
import org.jboss.logging.Logger;

import jakarta.annotation.Resource;
import jakarta.ejb.EJB;
import jakarta.ejb.Stateless;
import jakarta.ejb.TransactionAttribute;
import jakarta.ejb.TransactionAttributeType;
import jakarta.transaction.Transaction;
import jakarta.transaction.TransactionManager;

/**
 * Bean expected to be called by {@link ClientBean}.
 * Working with {@link javax.transaction.xa.XAResource}s to force the transaction manager to process
 * two-phase commit after the end of the business method.
 */
@Stateless
public class TransactionalBean implements TransactionalRemote {
    private static final Logger log = Logger.getLogger(TransactionalBean.class);

    @EJB
    private TransactionCheckerSingleton transactionCheckerSingleton;

    @Resource(lookup = "java:/TransactionManager")
    private TransactionManager tm;

    @TransactionAttribute(TransactionAttributeType.MANDATORY)
    public void enlistOnePersistentXAResource() {
        try {
            log.debugf("Invocation to #enlistOnePersistentXAResource with transaction", tm.getTransaction());
            tm.getTransaction().enlistResource(new PersistentTestXAResource(transactionCheckerSingleton));
        } catch (Exception e) {
            throw new IllegalStateException("Cannot enlist single " + PersistentTestXAResource.class.getSimpleName()
                    + " to transaction", e);
        }
    }

    @TransactionAttribute(TransactionAttributeType.MANDATORY)
    public void intermittentCommitFailure() {
        try {
            Transaction txn = tm.getTransaction();
            log.debugf("Invocation to #intermittentCommitFailure with the transaction: %s", txn);
            txn.enlistResource(new TestCommitFailureXAResource(transactionCheckerSingleton));
        } catch (Exception e) {
            throw new IllegalStateException("Cannot enlist single " + TestCommitFailureXAResource.class.getSimpleName()
                    + " to the transaction", e);
        }
    }

    @TransactionAttribute(TransactionAttributeType.MANDATORY)
    public void intermittentCommitFailureTwoPhase() {
        try {
            Transaction txn = tm.getTransaction();
            log.debugf("Invocation to #intermittentCommitFailure with transaction: %s", txn);
            txn.enlistResource(new TestCommitFailureXAResource(transactionCheckerSingleton));
            txn.enlistResource(new PersistentTestXAResource(transactionCheckerSingleton));
        } catch (Exception e) {
            throw new IllegalStateException("Cannot enlist one of the XAResources " + TestCommitFailureXAResource.class.getSimpleName()
                    + " or " + PersistentTestXAResource.class.getSimpleName() + " to the transaction", e);
        }
    }
}
